@@ -1,6 +1,11 @@
 #!/usr/bin/env bash
+
+# We have to explicitly start the ssh service
 sudo service ssh start
 
+# Enable the IPv6 interface
+echo 0 | sudo tee /proc/sys/net/ipv6/conf/all/disable_ipv6
+
 case "$ANDROID" in
     [Yy]* )
         emulator64-arm -avd android-armeabi-v7a -no-window -no-boot-anim -no-skin -no-audio -no-window -no-snapshot &
@@ -17,4 +22,4 @@ case "$ANDROID" in
         ;;
 esac
 
-PWNLIB_NOTERM=1 coverage run -m sphinx -b doctest docs/source docs/build/doctest $TARGET
+PWNLIB_NOTERM=1 coverage3 run -m sphinx -b doctest docs/source docs/build/doctest $TARGET
